diff -aurN a/memcache_pool.h b/memcache_pool.h
--- a/memcache_pool.h	2013-04-07 22:12:54.000000000 -0400
+++ b/memcache_pool.h	2017-05-19 16:04:45.262858090 -0400
@@ -135,8 +135,14 @@
 #define mmc_buffer_release(b) memset((b), 0, sizeof(*(b)))
 #define mmc_buffer_reset(b) (b)->value.len = (b)->idx = 0
 
-inline void mmc_buffer_alloc(mmc_buffer_t *, unsigned int);
-inline void mmc_buffer_free(mmc_buffer_t *);
+#if !defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
+#define MMC_POOL_INLINE inline
+#else
+#define MMC_POOL_INLINE __attribute__ ((gnu_inline)) inline
+#endif
+
+MMC_POOL_INLINE void mmc_buffer_alloc(mmc_buffer_t *, unsigned int);
+MMC_POOL_INLINE void mmc_buffer_free(mmc_buffer_t *);
 
 /* stream handlers */
 typedef struct mmc_stream mmc_stream_t;
@@ -391,8 +397,8 @@
 double timeval_to_double(struct timeval tv);
 struct timeval double_to_timeval(double sec);
 
-inline int mmc_prepare_key_ex(const char *, unsigned int, char *, unsigned int *);
-inline int mmc_prepare_key(zval *, char *, unsigned int *);
+MMC_POOL_INLINE int mmc_prepare_key_ex(const char *, unsigned int, char *, unsigned int *);
+MMC_POOL_INLINE int mmc_prepare_key(zval *, char *, unsigned int *);
 
 #define mmc_str_left(h, n, hlen, nlen) ((hlen) >= (nlen) ? memcmp((h), (n), (nlen)) == 0 : 0)
 
diff -aurN a/memcache_queue.h b/memcache_queue.h
--- a/memcache_queue.h	2013-04-07 22:12:54.000000000 -0400
+++ b/memcache_queue.h	2017-05-19 16:07:23.753983941 -0400
@@ -40,7 +40,11 @@
 #ifdef PHP_WIN32
 #define MMC_QUEUE_INLINE
 #else
+#if !defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
 #define MMC_QUEUE_INLINE inline
+#else
+#define MMC_QUEUE_INLINE __attribute__ ((gnu_inline)) inline
+#endif
 #endif
 
 MMC_QUEUE_INLINE void mmc_queue_push(mmc_queue_t *, void *);
diff -aurN a/memcache_pool.c b/memcache_pool.c
--- a/memcache_pool.c	2013-04-07 22:12:54.000000000 -0400
+++ b/memcache_pool.c	2017-05-19 16:22:51.592845885 -0400
@@ -40,7 +40,7 @@
 
 ZEND_DECLARE_MODULE_GLOBALS(memcache)
 
-inline void mmc_buffer_alloc(mmc_buffer_t *buffer, unsigned int size)  /*
+MMC_POOL_INLINE void mmc_buffer_alloc(mmc_buffer_t *buffer, unsigned int size)  /*
 	ensures space for an additional size bytes {{{ */
 {
 	register size_t newlen;
@@ -48,7 +48,7 @@
 }
 /* }}} */
 
-inline void mmc_buffer_free(mmc_buffer_t *buffer)  /* {{{ */
+MMC_POOL_INLINE void mmc_buffer_free(mmc_buffer_t *buffer)  /* {{{ */
 {
 	if (buffer->value.c != NULL) {
 		smart_str_free(&(buffer->value));
@@ -1676,7 +1676,7 @@
 }
 /* }}} */
 
-inline int mmc_prepare_key_ex(const char *key, unsigned int key_len, char *result, unsigned int *result_len)  /* {{{ */
+MMC_POOL_INLINE int mmc_prepare_key_ex(const char *key, unsigned int key_len, char *result, unsigned int *result_len)  /* {{{ */
 {
 	unsigned int i;
 	if (key_len == 0) {
@@ -1694,7 +1694,7 @@
 }
 /* }}} */
 
-inline int mmc_prepare_key(zval *key, char *result, unsigned int *result_len)  /* {{{ */
+MMC_POOL_INLINE int mmc_prepare_key(zval *key, char *result, unsigned int *result_len)  /* {{{ */
 {
 	if (Z_TYPE_P(key) == IS_STRING) {
 		return mmc_prepare_key_ex(Z_STRVAL_P(key), Z_STRLEN_P(key), result, result_len);
